/// <reference path="../../typings/tsd.d.ts" />
var Linter = (function () {
    function Linter(name, options) {
        this.options = options || {};
        if (name === 'markdownlint') {
            this.lint = this.markdownlint;
            this.lint_url = 'https://github.com/DavidAnson/markdownlint/blob/master/doc/Rules.md';
        }
        else if (name === 'mdast-lint') {
            this.lint = this.mdast_lint;
            this.lint_url = 'https://github.com/wooorm/mdast-lint/blob/master/doc/rules.md';
        }
        else if (name === 'none') {
            this.lint = function (f, c, p) { };
            this.lint_url = '';
        }
        else {
            console.log("linter.js: Invalid linter name '" + name + "'");
            this.lint = function (f, c, p) { };
            this.lint_url = '';
        }
    }
    Linter.prototype.markdownlint = function (filename, content, callback) {
        this.mdl = this.mdl || require('markdownlint');
        var opts = {
            strings: {},
            config: this.options
        };
        opts.strings[filename] = content;
        this.mdl(opts, function (err, result) {
            if (err) {
                return [];
            }
            var is_space = /\s+/;
            var messages = result.toString()
                .split("\n")
                .filter(function (msg) { return msg !== ''; })
                .map(function (msg) {
                var m = msg.match(is_space);
                if (!m) {
                    return { header: '', body: msg };
                }
                return {
                    header: msg.slice(0, m.index),
                    body: msg.slice(m.index)
                };
            });
            callback(messages);
        });
    };
    Linter.prototype.mdast_lint = function (filename, content, callback) {
        this.mdast = this.mdast || require('mdast')().use(require('mdast-lint'), this.options);
        this.mdast.process(content, function (err, _, file) {
            if (err) {
                return [];
            }
            callback(file.messages.map(function (m) {
                return {
                    header: filename + ":" + m.line + ":" + m.column + ":",
                    body: m.reason
                };
            }));
        });
    };
    return Linter;
})();
exports.default = Linter;
