var app_1 = require('app');
var marked = require('marked');
var path = require('path');
var fs = require('fs');
var chokidar = require('chokidar');
var highlight_js_1 = require('highlight.js');
var emoji_1 = require('./emoji');
var config = require('./config');
var linter_1 = require('./linter');
marked.setOptions({
    highlight: function (code, lang) {
        if (lang === undefined) {
            return code;
        }
        try {
            return highlight_js_1.highlight(lang, code).value;
        }
        catch (e) {
            console.log(e.message);
            return code;
        }
    }
});
var Watcher = (function () {
    function Watcher(path, render, renderLintResult) {
        this.path = path;
        this.render = render;
        this.renderLintResult = renderLintResult;
        this.config = config.load();
        this.linter = new linter_1.default(this.config.linter, this.config.lint_options);
        console.log('Watcher starts with ' + this.path);
        this.startWatching();
    }
    Watcher.prototype.startWatching = function () {
        var _this = this;
        if (this.file_watcher) {
            this.file_watcher.close();
        }
        if (!fs.existsSync(this.path)) {
            return;
        }
        if (fs.statSync(this.path).isFile()) {
            this.sendUpdate(this.path);
        }
        var ext_pattern = Object.keys(this.config.file_ext)
            .map(function (k) { return _this.config.file_ext[k].join('|'); })
            .join('|');
        var watched = path.join(this.path, '**', "*.(" + ext_pattern + ")");
        this.file_watcher = chokidar.watch(watched, {
            ignoreInitial: true,
            persistent: true,
            ignored: /[\\\/]\./
        });
        this.file_watcher.on('change', function (file) {
            console.log('File changed: ' + file);
            _this.sendUpdate(file);
        });
        this.file_watcher.on('add', function (file) {
            console.log('File added: ' + file);
            _this.sendUpdate(file);
        });
        this.file_watcher.on('error', function (error) {
            console.log("Error on watching: " + error);
        });
    };
    Watcher.prototype.sendUpdate = function (file) {
        var _this = this;
        var ext = path.extname(file).substr(1);
        if (ext === '') {
            return;
        }
        var kind = (function () {
            for (var k in _this.config.file_ext) {
                if (_this.config.file_ext[k].indexOf(ext) !== -1) {
                    return k;
                }
            }
            return '';
        })();
        switch (kind) {
            case 'markdown': {
                fs.readFile(file, 'utf8', function (err, text) {
                    if (err) {
                        console.log("Can't open: " + file);
                        return;
                    }
                    app_1.addRecentDocument(file);
                    _this.linter.lint(file, text, _this.renderLintResult);
                    var html = marked(text);
                    _this.render(kind, {
                        file: file,
                        html: emoji_1.replaceAll(html),
                    });
                });
                break;
            }
            case 'html': {
                this.render(kind, { file: file });
            }
        }
    };
    Watcher.prototype.changeWatchingDir = function (new_path) {
        if (new_path === this.path) {
            return;
        }
        console.log('Change watching path' + this.path + ' -> ' + new_path);
        this.path = new_path;
        this.startWatching();
    };
    Watcher.prototype.getLintRuleURL = function () {
        return this.linter.lint_url;
    };
    return Watcher;
})();
module.exports = Watcher;
