var initial_path = require('../../src/browser/initial_path');
var path = require('path');
context('InitialPath', function () {
    return describe('#initialPath()', function () {
        var argv = process.argv;
        afterEach(function () { return process.argv = argv; });
        it('returns cwd when no argument is specified in general platform', function () {
            process.argv = [];
            if (process.platform !== 'darwin') {
                assert.strictEqual(initial_path(), process.cwd());
            }
        });
        it('returns specific path when no argument is specified in darwin', function () {
            if (process.platform === 'darwin') {
                process.argv = [];
                var cwd = process.cwd();
                if (cwd === '/') {
                    assert.match(initial_path(), /Documents$/);
                }
                else {
                    assert.strictEqual(initial_path(), cwd);
                }
            }
        });
        it('returns the specified path if it exists', function () {
            process.argv = ['dummy', './README.md'];
            assert.strictEqual(initial_path(), path.resolve('./README.md'));
        });
        it('returns default path path if specified path does not exist', function () {
            process.argv = ['dummy', '/this/file/does/not/exist'];
            assert.strictEqual(initial_path(), process.cwd());
        });
        it('returns the last argument of argv', function () {
            process.argv = ['dummy', 'foo', 'bar', './README.md'];
            assert.strictEqual(initial_path(), path.resolve('./README.md'));
        });
    });
});
