var Watcher = require('../../src/browser/watcher');
var path_1 = require('path');
context('Watcher', function () {
    describe('#constructor', function () {
        it('is not undefined', function () { return assert.ok(Watcher); });
        it('generates watcher object', function () { return assert.ok(new Watcher('dummypath', function (a, b) { }, function (a) { })); });
    });
    it('starts watching specified file automatically', function (done) {
        var file = path_1.join(process.cwd(), 'README.md');
        var watcher = new Watcher(file, function (kind, content) {
            assert.strictEqual(kind, 'markdown');
            assert.strictEqual(watcher.path, file);
            done();
        }, function (a) { });
    });
    it('starts to lint specified file automatically', function (done) {
        var file = path_1.join(process.cwd(), 'README.md');
        var watcher = new Watcher(file, function (a, b) { }, function (msgs) { done(); });
    });
    describe('#changeWatchingDir()', function () {
        it('changes the watching dir', function (done) {
            var file = path_1.join(process.cwd(), 'README.md');
            var watcher = new Watcher(file, function (a, b) { }, function (a) { });
            var next_file = path_1.join(process.cwd(), 'docs', 'usage.md');
            var is_done = false;
            var done_once = function () {
                if (!is_done) {
                    done();
                    is_done = true;
                }
            };
            watcher.render = function (a, b) {
                assert.strictEqual(a, 'markdown');
                assert.strictEqual(watcher.path, next_file);
                done_once();
            };
            watcher.changeWatchingDir(next_file);
        });
        it('changes the linting dir', function (done) {
            var file = path_1.join(process.cwd(), 'README.md');
            var watcher = new Watcher(file, function (a, b) { }, function (a) { });
            var next_file = path_1.join(process.cwd(), 'docs', 'usage.md');
            var is_done = false;
            var done_once = function () {
                if (!is_done) {
                    done();
                    is_done = true;
                }
            };
            watcher.renderLintResult = function (m) { done_once(); };
            watcher.changeWatchingDir(next_file);
        });
    });
    describe('#getLintRuleURL', function () {
        it('returns lint URL', function () {
            var url = (new Watcher('dummy', function (a, b) { }, function (a) { })).getLintRuleURL();
            assert.ok(url);
            assert.match(url, /^https?:\/\//);
        });
    });
});
